@@ -1,19 +1,15 @@
-#!/sr/bin/python
-"""
-Mean curvature flow computation with implicit potential well.
-"""
+# Mean curvature flow computation with implicit potential well.
 
 from ufl import conditional
 from phasefield import PhaseStepper, PhaseModel
 
 from dune.fem.plotting import plotComponents
-from dune.grid import cartesianDomain
 
 class Mcf:
     """Sharp definition for mean curvature flow."""
-    omega = cartesianDomain([-2, -2], [2, 2], [3, 3])
+    omega = [-2, -2], [2, 2], [3, 3]
     endTime = 0.125
-    saveStep = 0.001
+    saveStep = 0.01
 
     mobility = 1
     def initial(x):
@@ -34,7 +30,6 @@ if __name__ == "__main__":
     phaseField = PhaseModel(Mcf, epsilon=0.03, dt=0.001)
 
     fempyBase = PhaseStepper(phaseField, solver = ("direct"))
-    solution = fempyBase.solution
 
     fempyBase.gridSetup(13, 13)
 
