@@ -1,21 +1,17 @@
-#!/usr/bin/python
-"""
-Mean curvature flow with obstacle potential well and uniform refinement
-"""
+# Mean curvature flow with obstacle potential well and uniform refinement
+
 from ufl import pi, sqrt, tanh
 from phasefield import PhaseStepper, PhaseModel
-from phasefield.auxfun import Obstacle
 
 from dune.fem.plotting import plotComponents
-from dune.grid import cartesianDomain
 
 from dune.fem.function import integrate
 
 class Mcf:
     """Sharp definition for mean curvature flow"""
-    omega = cartesianDomain([-2, -2], [2, 2], [3, 3])
+    omega = [-2, -2], [2, 2], [3, 3]
     endTime = 0.125
-    saveStep = 0.02
+    saveStep = 0.01
     fileBase = "McfObstacle"
 
     mobility = 1
@@ -31,23 +27,18 @@ class Mcf:
         return [[0, 1], [1, 0]]
 
 if __name__== "__main__":
-    import numpy as np
-    import matplotlib.pyplot as plt
-
-    # run epsilon from 0.02 to 0.03 in 6 increments
-    maxLevel = 20
+    maxLevel = 15
     dt = 1e-4
-    epsilon = 0.02
+    epsilon = 0.04
 
     phaseField = PhaseModel(Mcf, constrained=True, epsilon=epsilon, dt=dt)
 
     fempyBase = PhaseStepper(phaseField)
 
+    fempyBase.defaultRefine = [1.4, 0.2, 4, maxLevel]
     fempyBase.gridSetup(13, maxLevel)
-    fempyBase.defaultRefine = [1.4, 1.2, 4, maxLevel]
 
-    solution = fempyBase.solution
     while fempyBase.time < Mcf.endTime:
-        print(fempyBase.time)
+        print(fempyBase.time, flush=True)
         fempyBase.nextTime()
         fempyBase.adapt()
