@@ -1,16 +1,14 @@
 import math
 from dune.fem.plotting import plotComponents
 
-from phasefield import PhaseStepper, PhaseModel
-from phasefield.auxfun import SimpleInterpolate
+from phasefield import PhaseStepper, PhaseModel, SimpleInterpolate
 
 from ufl import conditional, grad
 
-from dune.grid import cartesianDomain
-
 class Ms:
-    omega = cartesianDomain([0, 0], [2, 2], [3, 3])
+    omega = [0, 0], [2, 2], [3, 3]
     endTime = 0.05
+    saveStep = 0.005
     mobility = 0.
 
     def initial(x):
@@ -44,16 +42,14 @@ solverParameters = {"fem.solver.newton.tolerance": 1e-9,
 
 phaseField = PhaseModel(Ms, epsilon=0.15*math.sqrt(3/4), dt=1e-4)
 
-phaseField.interpolate = SimpleInterpolate()
+phaseField.interpolate = SimpleInterpolate
 
 fempyBase = PhaseStepper(phaseField, solverParameters)
 
 fempyBase.gridSetup(12, 12)
 
-solution = fempyBase.solution
-
 while fempyBase.time < Ms.endTime:
-    print(fempyBase.timte)
+    print(fempyBase.time)
     fempyBase.nextTime()
     fempyBase.adapt()
 
