@@ -1,26 +1,18 @@
-from ufl import conditional, sqrt, tanh
+import math
+import numpy as np
+import matplotlib.pyplot as plt
+import ufl
+from ufl import conditional, sqrt, tanh, pi, sqrt
 from phasefield import PhaseStepper, PhaseModel
 
 from dune.fem.function import levelFunction, partitionFunction
 from dune.grid import cartesianDomain
-import math
-
-epsilon = 0.03
-
-
-from phasefield.auxfun import ConcaveConvex3p, Implicit3p
-
-
-import ufl
-from ufl import pi, sqrt
-from phasefield import PhaseStepper, PhaseModel
-from phasefield.auxfun import ConcaveConvex
-
 from dune.fem.plotting import plotComponents
 from dune.grid import cartesianDomain
-
 from dune.fem.function import integrate
 
+from phasefield import PhaseStepper, PhaseModel, ConcaveConvex, ConcaveConvex3p, Implicit3p
+
 def compute(baseName, maxLevel, epsilon, dt):
     r0 = 0.5
 
@@ -40,8 +32,8 @@ def compute(baseName, maxLevel, epsilon, dt):
                      0.5+0.5*ufl.tanh((1/epsilon)*(x[0]*x[0]+x[1]*x[1]-r0*r0)),0]]
 
 
-    from phasefield.auxfun import ConcaveConvex3p, Implicit3p
-    phaseField = PhaseModel(Iso3, epsilon=epsilon, dt=dt, well = Implicit3p)
+    phaseField = PhaseModel(Iso3, epsilon=epsilon, dt=dt)
+    phaseField.well = Implicit3p
 
     fempyBase = PhaseStepper(phaseField)
 
@@ -52,19 +44,18 @@ def compute(baseName, maxLevel, epsilon, dt):
     radiusVec = []
     while fempyBase.time < Iso3.endTime:
         if fempyBase.saveTime is not None and fempyBase.saveTime <= fempyBase.time +dt:
-            print("saving")
             radius = sqrt(integrate(fempyBase.gridView,solution,4)[0]/pi)
             radiusVec.append(radius)
         fempyBase.nextTime()
         fempyBase.adapt()
     return radiusVec
 
-import numpy as np
-import matplotlib.pyplot as plt
-
 maxLevel = 13
 dt = 1e-3
 
+# carry out a sequence of simulations with different value for epsilon
+# for a given 'epsilon' the result is stored in a dictonary for later postprocessing
+
 try:
     myDict = np.load('Iso3IMsim.npy', allow_pickle='TRUE').item()
 except FileNotFoundError:
@@ -77,7 +68,6 @@ except FileNotFoundError:
         t += dt
     myDict['exact'] = exactList
 
-#for eps in np.linspace(0.03, 0.02, 6):
 for eps in np.linspace(0.05, 0.01, 9):
     if (maxLevel, eps, dt) in myDict:
         print("sim found in dict using old value")
@@ -97,6 +87,3 @@ for key, value in myDict.items():
 
 plt.legend()
 plt.show()
-
-
-
